==> localnews-msg-service-1.3.1-20190117.154030-2-sources.jar: com/bxm/localnews/mq/config/AliyunMqConsumeConfiguration.java <==
package com.bxm.localnews.mq.config;

import com.aliyun.openservices.ons.api.MessageListener;
import com.aliyun.openservices.ons.api.bean.ConsumerBean;
import com.aliyun.openservices.ons.api.bean.Subscription;
import com.bxm.localnews.mq.consume.listener.DefaultMessageListener;
import com.bxm.localnews.mq.consume.listener.PushMessageListener;
import com.bxm.localnews.mq.consume.listener.SmsMessageListener;
import com.google.common.collect.Maps;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Map;
import java.util.Properties;

/**
 * 阿里云消息队列配置
 * @author liujia 2018/7/27 14:25
 */
@Component
@Configuration
@ConditionalOnProperty(prefix = "aliyun.mq", value = "access-key")
@EnableConfigurationProperties(AliyunMqProperties.class)
@Profile({"test", "prod"})
public class AliyunMqConsumeConfiguration {

    @Resource
    private AliyunMqProperties aliyunMqProperties;

    @Resource
    private DefaultMessageListener defaultMessageListener;

    @Resource
    private SmsMessageListener smsMessageListener;

    @Resource
    private PushMessageListener pushMessageListener;

    /**
     * 业务消息队列消费者
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean consumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty("ConsumerId", this.aliyunMqProperties.getConsumerId());
        properties.setProperty("AccessKey", this.aliyunMqProperties.getAccessKey());
        properties.setProperty("SecretKey", this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getTopic());
        subscription.setExpression("*");

        defaultMessageListener.init();
        subscriptionTable.put(subscription, this.defaultMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

    /**
     * 短信消费者
     * @return
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean smsConsumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty("ConsumerId", this.aliyunMqProperties.getSmsConsumerId());
        properties.setProperty("AccessKey", this.aliyunMqProperties.getAccessKey());
        properties.setProperty("SecretKey", this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getSmsTopic());
        subscription.setExpression("*");

        subscriptionTable.put(subscription, this.smsMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

    /**
     * 推送消息消费者
     * @return
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean pushConsumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty("ConsumerId", this.aliyunMqProperties.getPushConsumerId());
        properties.setProperty("AccessKey", this.aliyunMqProperties.getAccessKey());
        properties.setProperty("SecretKey", this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getPushTopic());
        subscription.setExpression("*");

        subscriptionTable.put(subscription, this.pushMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

}

==> localnews-msg-service-1.3.7-sources.jar: com/bxm/localnews/mq/config/AliyunMqConsumeConfiguration.java <==
package com.bxm.localnews.mq.config;

import java.util.Map;
import java.util.Properties;

import javax.annotation.Resource;

import com.aliyun.openservices.ons.api.MessageListener;
import com.aliyun.openservices.ons.api.PropertyKeyConst;
import com.aliyun.openservices.ons.api.bean.ConsumerBean;
import com.aliyun.openservices.ons.api.bean.Subscription;
import com.bxm.localnews.mq.consume.listener.DefaultMessageListener;
import com.bxm.localnews.mq.consume.listener.NewsMessageListener;
import com.bxm.localnews.mq.consume.listener.PushMessageListener;
import com.bxm.localnews.mq.consume.listener.SmsMessageListener;
import com.google.common.collect.Maps;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.stereotype.Component;

/**
 * 阿里云消息队列配置
 *
 * @author liujia 2018/7/27 14:25
 */
@Component
@Configuration
@ConditionalOnProperty(prefix = "aliyun.mq", value = "access-key")
@EnableConfigurationProperties(AliyunMqProperties.class)
//@Profile({"test", "prod"})
public class AliyunMqConsumeConfiguration {

    @Resource
    private AliyunMqProperties aliyunMqProperties;

    @Resource
    private DefaultMessageListener defaultMessageListener;

    @Resource
    private SmsMessageListener smsMessageListener;

    @Resource
    private PushMessageListener pushMessageListener;

    @Resource
    private NewsMessageListener newsMessageListener;

    /**
     * 业务消息队列消费者
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean consumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty(PropertyKeyConst.ConsumerId, this.aliyunMqProperties.getConsumerId());
        properties.setProperty(PropertyKeyConst.AccessKey, this.aliyunMqProperties.getAccessKey());
        properties.setProperty(PropertyKeyConst.SecretKey, this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getTopic());
        subscription.setExpression("*");

        defaultMessageListener.init();
        subscriptionTable.put(subscription, this.defaultMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

    /**
     * 短信消费者
     *
     * @return
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean smsConsumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty(PropertyKeyConst.ConsumerId, this.aliyunMqProperties.getSmsConsumerId());
        properties.setProperty(PropertyKeyConst.AccessKey, this.aliyunMqProperties.getAccessKey());
        properties.setProperty(PropertyKeyConst.SecretKey, this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getSmsTopic());
        subscription.setExpression("*");

        subscriptionTable.put(subscription, this.smsMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

    /**
     * 推送消息消费者
     *
     * @return
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean pushConsumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.setProperty(PropertyKeyConst.ConsumerId, this.aliyunMqProperties.getPushConsumerId());
        properties.setProperty(PropertyKeyConst.AccessKey, this.aliyunMqProperties.getAccessKey());
        properties.setProperty(PropertyKeyConst.SecretKey, this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getPushTopic());
        subscription.setExpression("*");

        subscriptionTable.put(subscription, this.pushMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }


    /**
     * 新闻消息消费者
     *
     * @return
     */
    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public ConsumerBean newsConsumerBean() {
        ConsumerBean consumerBean = new ConsumerBean();

        Properties properties = new Properties();
        properties.put(PropertyKeyConst.GROUP_ID, this.aliyunMqProperties.getNewsGroupId());
        properties.setProperty(PropertyKeyConst.AccessKey, this.aliyunMqProperties.getAccessKey());
        properties.setProperty(PropertyKeyConst.SecretKey, this.aliyunMqProperties.getAccessSecret());

        consumerBean.setProperties(properties);

        Map<Subscription, MessageListener> subscriptionTable = Maps.newHashMap();

        Subscription subscription = new Subscription();
        subscription.setTopic(this.aliyunMqProperties.getNewsTopic());
        subscription.setExpression("*");

        this.newsMessageListener.init();
        subscriptionTable.put(subscription, this.newsMessageListener);

        consumerBean.setSubscriptionTable(subscriptionTable);
        return consumerBean;
    }

}
